diff --git a/README b/README
index a735a0dbbe6d9fb3d44c47a044ffbedfaec6d4a2..9020a9953706ea8f8ff32981a55d1c326e7cb350 100644
--- a/README
+++ b/README
@@ -20,7 +20,7 @@ Unit tests
 ----------
 
 The unit tests depend on a running batch daemon, webserver, and SOAP
-webservice:
+web service:
 
     sudo /etc/init.d/mutalyzer-batchd start
     sudo /etc/init.d/apache2 start
@@ -135,8 +135,8 @@ Todo list:
   for example jinja.
 - Develop a large test suite.
 - Create a web interface url to watch the progress of a batch job.
-- Create webservices for the batch jobs (steal ideas from Jeroen's DVD
-  webservice).
+- Create web services for the batch jobs (steal ideas from Jeroen's DVD
+  web service).
 - Use virtualenv?
 - Use SQLAlchemy?
 - Password for MySQL user.
diff --git a/bin/mutalyzer-json-service.wsgi b/bin/mutalyzer-json-service.wsgi
index 4e2f98020a74e7c2bf80cbb4d7631c6cfa47cc78..bb7dc7d930b64b2711eaf1c5a15bca5d5ac611c9 100755
--- a/bin/mutalyzer-json-service.wsgi
+++ b/bin/mutalyzer-json-service.wsgi
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """
-WSGI interface to the Mutalyzer HTTP/RPC+JSON webservice.
+WSGI interface to the Mutalyzer HTTP/RPC+JSON web service.
 
 The WSGI interface is exposed through the module variable 'application'.
 
diff --git a/bin/mutalyzer-soap-service.wsgi b/bin/mutalyzer-soap-service.wsgi
index 79fe02e17b3a59e40af2a6ad93d5a36721b96973..5467bb910f1a57a0c3d923e38fb15c7dfd25f8f6 100755
--- a/bin/mutalyzer-soap-service.wsgi
+++ b/bin/mutalyzer-soap-service.wsgi
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """
-WSGI interface to the Mutalyzer SOAP webservice.
+WSGI interface to the Mutalyzer SOAP web service.
 
 The WSGI interface is exposed through the module variable 'application'.
 
diff --git a/extras/apache/mutalyzer.conf b/extras/apache/mutalyzer.conf
index 0142a57666db70f5cbc57ca2c625c2cd0092deee..69b816add3a7d6159ace79ef4a87a9eb6ccc8e11 100644
--- a/extras/apache/mutalyzer.conf
+++ b/extras/apache/mutalyzer.conf
@@ -11,7 +11,7 @@ Alias /mutalyzer/base /var/www/mutalyzer/base
 WSGIDaemonProcess mutalyzer processes=2 threads=15 maximum-requests=10000
 WSGIProcessGroup mutalyzer
 
-# SOAP/1.1 webservice
+# SOAP/1.1 web service
 WSGIScriptAlias /mutalyzer/services <MUTALYZER_BIN_SOAP_SERVICE>
 <Directory /mutalyzer/services>
     Order deny,allow
@@ -19,7 +19,7 @@ WSGIScriptAlias /mutalyzer/services <MUTALYZER_BIN_SOAP_SERVICE>
     Options -Indexes
 </Directory>
 
-# HTTP/RPC+JSON webservice
+# HTTP/RPC+JSON web service
 WSGIScriptAlias /mutalyzer/json <MUTALYZER_BIN_JSON_SERVICE>
 <Directory /mutalyzer/json>
     Order deny,allow
diff --git a/extras/migrations/007-apache-json-webservice.migration b/extras/migrations/007-apache-json-webservice.migration
index cd9b82784e59c2b3db54ffce99d252f3312342da..e4bf006ba58ed711db7b05df346a14e1b3698428 100755
--- a/extras/migrations/007-apache-json-webservice.migration
+++ b/extras/migrations/007-apache-json-webservice.migration
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Add HTTP/RPC+JSON webservice entry to Apache configuration.
+# Add HTTP/RPC+JSON web service entry to Apache configuration.
 #
 # Usage:
 #   ./007-apache-json-webservice.migration [migrate]
diff --git a/extras/soap-tools/checkSyntax.py b/extras/soap-tools/checkSyntax.py
index decfbc13b42f59243c431c1a143c5ecef0d8a80a..78c63e5c902e25d0944b744dfc04691ef6053f40 100755
--- a/extras/soap-tools/checkSyntax.py
+++ b/extras/soap-tools/checkSyntax.py
@@ -7,8 +7,8 @@ Usage:
 
   description: Variant description to check.
 
-The syntaxchecker results are retrieved from the Mutalyzer SOAP webservice and
-printed to standard output.
+The syntaxchecker results are retrieved from the Mutalyzer SOAP web service
+and printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/chromAccession.py b/extras/soap-tools/chromAccession.py
index 614947543d4201b3eff91e762fc64f3bf71cb650..4fb6e04f1b3baa844bcf50c31f6dd3f826c7ce73 100755
--- a/extras/soap-tools/chromAccession.py
+++ b/extras/soap-tools/chromAccession.py
@@ -8,7 +8,7 @@ Usage:
   chromosome: Chromosome to get accession number for, e.g. 'chr2'.
   build: Human genome build, 'hg18' or 'hg19' (default: 'hg19').
 
-The accession number is retrieved from the Mutalyzer SOAP webservice and
+The accession number is retrieved from the Mutalyzer SOAP web service and
 printed to standard output.
 """
 
diff --git a/extras/soap-tools/descriptionExtract.py b/extras/soap-tools/descriptionExtract.py
index d1ff2b90bc313e97f5a0986f9fc00430fb809906..7ca3b2eceefa27fa53b1f41794a8d92dd36b1bba 100755
--- a/extras/soap-tools/descriptionExtract.py
+++ b/extras/soap-tools/descriptionExtract.py
@@ -9,8 +9,8 @@ Usage:
   reference: Reference DNA sequence.
   observed: Observed DNA sequence.
 
-The extracted HGVS description is retrieved from the Mutalyzer SOAP webservice
-and printed to standard output.
+The extracted HGVS description is retrieved from the Mutalyzer SOAP web
+service and printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/getCache.py b/extras/soap-tools/getCache.py
index cc8ecc18c20568193e0ae3da681537c4473f261d..2f9c7df218b3c831964671a622f6f44d14f4d039 100755
--- a/extras/soap-tools/getCache.py
+++ b/extras/soap-tools/getCache.py
@@ -7,8 +7,8 @@ Usage:
 
   days: Retrieve entries of at most this number of days old.
 
-The cache entries are retrieved from the Mutalyzer SOAP webservice and printed
-to standard output.
+The cache entries are retrieved from the Mutalyzer SOAP web service and
+printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/getGeneAndTranscript.py b/extras/soap-tools/getGeneAndTranscript.py
index 979e52d99ac97196b5a729f27bc369ac45590444..8946d59e71c8fb280b4e4e240acdd019f3fe24bd 100755
--- a/extras/soap-tools/getGeneAndTranscript.py
+++ b/extras/soap-tools/getGeneAndTranscript.py
@@ -9,7 +9,7 @@ Usage:
   transcript_reference: Reference of the transcript to lookup.
 
 The transcript and product name are retrieved from the Mutalyzer SOAP
-webservice and printed to standard output.
+web service and printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/getTranscripts.py b/extras/soap-tools/getTranscripts.py
index 310fb3fa96ada76b61906940b111d3b8aaa387af..51052fca68208719de8002af8b44418120180eb3 100755
--- a/extras/soap-tools/getTranscripts.py
+++ b/extras/soap-tools/getTranscripts.py
@@ -9,7 +9,7 @@ Usage:
   position: Position to lookup overlapping transcripts for.
 
 The transcript accession numbers are retrieved from the Mutalyzer SOAP
-webservice and printed to standard output.
+web service and printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/getTranscriptsAndInfo.py b/extras/soap-tools/getTranscriptsAndInfo.py
index ee5a9e72ddee475713f003527cee930d625688cd..86dc3ff446887e970cd6c521b998629848904943 100755
--- a/extras/soap-tools/getTranscriptsAndInfo.py
+++ b/extras/soap-tools/getTranscriptsAndInfo.py
@@ -9,8 +9,8 @@ Usage:
       example 'AL449423.14'.
   gene: Optionally restrict results to transcripts for this gene.
 
-The transcript information is retrieved from the Mutalyzer SOAP webservice and
-printed to standard output.
+The transcript information is retrieved from the Mutalyzer SOAP web service
+and printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/getTranscriptsByGeneName.py b/extras/soap-tools/getTranscriptsByGeneName.py
index d757dcf1d3a2fe7f0f24f74a9af9d1efdd5b134e..d7789a0acbe91b85aef602f9771f25dfd13068a6 100755
--- a/extras/soap-tools/getTranscriptsByGeneName.py
+++ b/extras/soap-tools/getTranscriptsByGeneName.py
@@ -8,7 +8,7 @@ Usage:
   gene: Gene name to lookup transcripts for.
 
 The transcript accession numbers are retrieved from the Mutalyzer SOAP
-webservice and printed to standard output.
+web service and printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/getTranscriptsMapping.py b/extras/soap-tools/getTranscriptsMapping.py
index 3aacfab6fedf6ace5e1ea891ffb6d1d9d442dd69..79683369ed86b478aabc89c20c9195634a65a3f2 100755
--- a/extras/soap-tools/getTranscriptsMapping.py
+++ b/extras/soap-tools/getTranscriptsMapping.py
@@ -11,8 +11,8 @@ Usage:
   pos2: End of chromosomal region, e.g. 230938269.
   tolerant: Optionally set region matching to be tolerant, e.g. 1.
 
-The transcript information is retrieved from the Mutalyzer SOAP webservice and
-printed to standard output.
+The transcript information is retrieved from the Mutalyzer SOAP web service
+and printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/getdbSNPDescriptions.py b/extras/soap-tools/getdbSNPDescriptions.py
index 11cc54a803ec40804dc292e50a29ae74ed9fd745..f5745533067a6e675077d5b9756bd9b7fcd75160 100755
--- a/extras/soap-tools/getdbSNPDescriptions.py
+++ b/extras/soap-tools/getdbSNPDescriptions.py
@@ -7,7 +7,7 @@ Usage:
 
   rs_number: A valid dbSNP rs number, e.g. 'rs9919552'.
 
-The HGVS descriptions are retrieved from the Mutalyzer SOAP webservice and
+The HGVS descriptions are retrieved from the Mutalyzer SOAP web service and
 printed to standard output.
 """
 
diff --git a/extras/soap-tools/info.py b/extras/soap-tools/info.py
index e7f80ef343d25a4f123dc70ae3e099173e805722..eb3cd058044621745a59d464bcfd70ca57602a19 100755
--- a/extras/soap-tools/info.py
+++ b/extras/soap-tools/info.py
@@ -5,7 +5,7 @@ Get static version information from a Mutalyzer installation.
 Usage:
   {command}
 
-The version information is retrieved from the Mutalyzer SOAP webservice and
+The version information is retrieved from the Mutalyzer SOAP web service and
 printed to standard output.
 """
 
diff --git a/extras/soap-tools/mappingInfo.py b/extras/soap-tools/mappingInfo.py
index 3fc0dda3b3a346b3c9e753f68d1dd9c0875e8f44..49fb4ac404df042d044ce9b6525e2084a8a992f0 100755
--- a/extras/soap-tools/mappingInfo.py
+++ b/extras/soap-tools/mappingInfo.py
@@ -9,7 +9,7 @@ Usage:
   variant: Variant to map, e.g. 'g.112039014G>T'.
   build: Human genome build, 'hg18' or 'hg19' (default: 'hg19').
 
-The mapping information is retrieved from the Mutalyzer SOAP webservice and
+The mapping information is retrieved from the Mutalyzer SOAP web service and
 printed to standard output.
 """
 
diff --git a/extras/soap-tools/numberConversion.py b/extras/soap-tools/numberConversion.py
index f72fb5320b6410f00b2d1d28fff4681b41330f70..977bbc719ce83dd34b2047add81ff55cdd978fa8 100755
--- a/extras/soap-tools/numberConversion.py
+++ b/extras/soap-tools/numberConversion.py
@@ -9,7 +9,7 @@ Usage:
   description: Variant description to convert.
 
 The converted HGVS description(s) is (are) retrieved from the Mutalyzer SOAP
-webservice and printed to standard output.
+web service and printed to standard output.
 """
 
 
diff --git a/extras/soap-tools/runMutalyzer.py b/extras/soap-tools/runMutalyzer.py
index 6cdc469749ac468fbda67fea1ca4b3ad69a9778f..852e467b5fe86e2809b9d3e9ef6eb633afcbcab2 100755
--- a/extras/soap-tools/runMutalyzer.py
+++ b/extras/soap-tools/runMutalyzer.py
@@ -8,7 +8,7 @@ Usage:
   description: Variant description to check.
   verbosity: If 'verbose', also output full original and variant sequences.
 
-The namechecker results are retrieved from the Mutalyzer SOAP webservice and
+The namechecker results are retrieved from the Mutalyzer SOAP web service and
 printed to standard output.
 """
 
diff --git a/extras/soap-tools/sliceChromosomeByGene.py b/extras/soap-tools/sliceChromosomeByGene.py
index 698a927cfd5a155c9d7484813c843ffc7b0f381c..8e24c54d9b9a9a16cdebcb75fb836e7e6a9b66bc 100755
--- a/extras/soap-tools/sliceChromosomeByGene.py
+++ b/extras/soap-tools/sliceChromosomeByGene.py
@@ -8,7 +8,7 @@ Usage:
   gene: Gene symbol of the gene to slice.
 
 A slice containing the gene with 5000 upstream bases and 2000 downstream bases
-is created with the Mutalyzer SOAP webservice. The resulting UD number is
+is created with the Mutalyzer SOAP web service. The resulting UD number is
 printed to standard output.
 """
 
diff --git a/extras/soap-tools/sp.py b/extras/soap-tools/sp.py
index 29fa90198636567eced291eca4534cf2f4de6e7a..d395d1993195a7664d6daa3ac05c7e7f2c3476f6 100755
--- a/extras/soap-tools/sp.py
+++ b/extras/soap-tools/sp.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Example SOAP client for the Mutalyzer webservice in Python using the
+# Example SOAP client for the Mutalyzer web service in Python using the
 # SOAPpy library.
 #
 # See http://www.mutalyzer.nl/2.0/webservices
diff --git a/extras/soap-tools/transcriptInfo.py b/extras/soap-tools/transcriptInfo.py
index eaeb5792285abf981b9b4f3c65f97d061547b7d8..d25d361a94461572ebd600ac165b3513d8dea92e 100755
--- a/extras/soap-tools/transcriptInfo.py
+++ b/extras/soap-tools/transcriptInfo.py
@@ -7,8 +7,8 @@ Usage:
 
   transcript: Transcript accession number, e.g. 'NM_002001.2'.
 
-The transcript information is retrieved from the Mutalyzer SOAP webservice and
-printed to standard output.
+The transcript information is retrieved from the Mutalyzer SOAP web service
+and printed to standard output.
 """
 
 
diff --git a/mutalyzer/models.py b/mutalyzer/models.py
index 9f5622a6d0447a4940c9baa44588b0a00d076bac..dcb530ed5d5ce08b5c1ec64f2358bc1581e21286 100644
--- a/mutalyzer/models.py
+++ b/mutalyzer/models.py
@@ -1,5 +1,5 @@
 """
-Collection of serilizable objects used by the SOAP webservice. They extend
+Collection of serilizable objects used by the SOAP web service. They extend
 from the spyne ClassModel.
 
 Default attributes for the spyne ClassModel:
diff --git a/mutalyzer/services/json.py b/mutalyzer/services/json.py
index ae94a5032dc537656261aa60080d87f95710ac55..bcf35ec6307cd6c714afcf623ae4a461a9bd9fd0 100644
--- a/mutalyzer/services/json.py
+++ b/mutalyzer/services/json.py
@@ -1,5 +1,5 @@
 """
-Mutalyzer webservice HTTP/RPC with JSON response payloads.
+Mutalyzer web service HTTP/RPC with JSON response payloads.
 """
 
 
diff --git a/mutalyzer/services/rpc.py b/mutalyzer/services/rpc.py
index 0270a19486bbca21f9d7860f6ed88d5f5fe19589..a655b2fdc846e9ef65ac0f03fd45003ef054971b 100644
--- a/mutalyzer/services/rpc.py
+++ b/mutalyzer/services/rpc.py
@@ -118,7 +118,7 @@ def _checkVariant(L, variant) :
 
 class MutalyzerService(ServiceBase):
     """
-    Mutalyzer webservices.
+    Mutalyzer web services.
 
     These methods are made public via a SOAP interface.
     """
diff --git a/mutalyzer/services/soap.py b/mutalyzer/services/soap.py
index e442b9d0f7b7fd045bdb505d1ac02379f89ba591..278841d00b83350058cfdfa99bb854cc42a01b46 100644
--- a/mutalyzer/services/soap.py
+++ b/mutalyzer/services/soap.py
@@ -1,5 +1,5 @@
 """
-Mutalyzer SOAP/1.1 webservice.
+Mutalyzer SOAP/1.1 web service.
 """
 
 
diff --git a/mutalyzer/templates/about.html b/mutalyzer/templates/about.html
index c23771259428bcdbcdc7f27bcc8e10b870ea70b9..a0ec831295314e6577f856949c83b1eb35cd485e 100644
--- a/mutalyzer/templates/about.html
+++ b/mutalyzer/templates/about.html
@@ -13,7 +13,7 @@
       <ul>
         <li>The LRG parser, as well as the Batch interfaces are written
             by Gerben R. Stouten.</li>
-        <li>The position converter interfaces (webservice and WWW) are
+        <li>The position converter interfaces (web service and WWW) are
             written by Gerard C.P. Schaafsma.</li>
         <li>Current development and maintenance is done by Martijn
             Vermaat.</li>
diff --git a/mutalyzer/templates/client-mono.cs b/mutalyzer/templates/client-mono.cs
index 0168ec39ad08dfa8420b2f10c1c437fe078ce9a6..b3baac66149b9691e12ee04f90df4671e8d23137 100644
--- a/mutalyzer/templates/client-mono.cs
+++ b/mutalyzer/templates/client-mono.cs
@@ -1,5 +1,5 @@
 /*
-  Example SOAP client for the Mutalyzer webservice in C# for the Mono
+  Example SOAP client for the Mutalyzer web service in C# for the Mono
   platform.
 
   See {path}/webservices
diff --git a/mutalyzer/templates/client-php.php b/mutalyzer/templates/client-php.php
index 975eaad3e9e755efd758bec50fd4ffef661f981d..ccf52c85cd2289a7a523c38a7584298cd50a3d88 100644
--- a/mutalyzer/templates/client-php.php
+++ b/mutalyzer/templates/client-php.php
@@ -1,7 +1,7 @@
 <?php
 
 /*
- Example SOAP client for the Mutalyzer webservice in PHP.
+ Example SOAP client for the Mutalyzer web service in PHP.
 
  See {path}/webservices
 
diff --git a/mutalyzer/templates/client-savon.rb b/mutalyzer/templates/client-savon.rb
index a411ebeb282d075f2d67c25877bfaaee178c81e7..5404fba5b5133ded1497e93bdb55c86a4009a33c 100644
--- a/mutalyzer/templates/client-savon.rb
+++ b/mutalyzer/templates/client-savon.rb
@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 
-# Example SOAP client for the Mutalyzer webservice in Ruby using the savon
+# Example SOAP client for the Mutalyzer web service in Ruby using the savon
 # library.
 #
 # See {path}/webservices
diff --git a/mutalyzer/templates/client-soappy.py b/mutalyzer/templates/client-soappy.py
index 1d74d9c94105e3db730b2a6ae67993e5d285a8e1..4b503dda6db774cd210d1fb9c3771579ce836614 100644
--- a/mutalyzer/templates/client-soappy.py
+++ b/mutalyzer/templates/client-soappy.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Example SOAP client for the Mutalyzer webservice in Python using the
+# Example SOAP client for the Mutalyzer web service in Python using the
 # SOAPpy library.
 #
 # See {path}/webservices
diff --git a/mutalyzer/templates/client-suds.py b/mutalyzer/templates/client-suds.py
index dc97fab4f7deb597a6acfccbb387f3d3fa72eefd..46ea68f986791fada75efdb7a5d6da10d9a5894d 100644
--- a/mutalyzer/templates/client-suds.py
+++ b/mutalyzer/templates/client-suds.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Example SOAP client for the Mutalyzer webservice in Python using the
+# Example SOAP client for the Mutalyzer web service in Python using the
 # suds library.
 #
 # See {path}/webservices
diff --git a/mutalyzer/templates/help.html b/mutalyzer/templates/help.html
index c6c7f4fdb17af28e089bd6cc6e87505cade9c30e..448d0824a9d3e9abfe9b826d4dae85a2ec5950d5 100644
--- a/mutalyzer/templates/help.html
+++ b/mutalyzer/templates/help.html
@@ -11,20 +11,20 @@
         Mutalyzer is a tool primarily designed to check descriptions of
         sequence variants according to the standard human sequence variant
         nomenclature of the Human Genome Sequence Variation Society
-        (<a href="http://www.hgvs.org/">HGVS</a>) (For an overview, visit 
+        (<a href="http://www.hgvs.org/">HGVS</a>) (For an overview, visit
         <a href="http://www.hgvs.org/mutnomen/"
           >http://www.hgvs.org/mutnomen/</a>).
         Mutalyzer aims to encourage the proper use of&nbsp; nomenclature in
         publications and reduce redundancy in sequence variation databases. In
         principle, Mutalyzer can check descriptions of sequence variants
         detected in other organisms, provided that the standard HGVS
-        nomenclature is applied. 
+        nomenclature is applied.
       </p>
 
       <h3>Mutalyzer 2 flow</h3>
       <p>
         The user specifies a reference sequence (file) and a variant using the
-        <a href="#NameGenerator">Name Generator</a> or the 
+        <a href="#NameGenerator">Name Generator</a> or the
         <a href="#NameChecker">Name checker</a> interface. The Name Generator
         builds the complete variant description for the Name Checker (e.g.,
         Mutalyzer uses this input to perform the nomenclature check in the
@@ -32,8 +32,8 @@
       </p>
       <p>
         1) Retriever: retrieves
-        <a href="#Ref">reference sequence records</a> from the 
-        <a href="http://www.ncbi.nlm.nih.gov/">NCBI</a> or 
+        <a href="#Ref">reference sequence records</a> from the
+        <a href="http://www.ncbi.nlm.nih.gov/">NCBI</a> or
         <a href="http://www.lrg-sequence.org/">LRG</a> websites.
       </p>
       <p>
@@ -76,7 +76,7 @@
           different checkers that accept a large list of descriptions as input.
       </p>
       <p>
-        - <a href="#Webservices">Webservices</a>: programmatic access to
+        - <a href="#Webservices">Web services</a>: programmatic access to
           Mutalyzer's functionality.
       </p>
       <p>&nbsp;</p>
@@ -99,18 +99,18 @@
         1) GenBank files
       </p>
       <p>
-        GenBank records (e.g., NG_007400.1) are specified by a 
+        GenBank records (e.g., NG_007400.1) are specified by a
         <i>GenBank accession number</i> (NG_007400) and a version number (.1).
         Omission of the version number automatically results in selection of
         the most recent version of that record. In case of outdated versions,
-        Mutalyzer will issue a warning. Alternatively, the unique 
+        Mutalyzer will issue a warning. Alternatively, the unique
         <i>GenInfo identifier</i> (gi) of the reference sequence (e.g.,
         4506864) can be used with or without the letters ''gi'';.
         Mutalyzer does not accept GenBank records containing no sequence (e.g.
         chromosomal reference sequence identifiers referring to contig
         accession numbers) or files larger than 10 MB. Mutalyzer also accepts
         user-defined files in GenBank format, including slices of chromosomal
-        reference sequences. These files are specified by unique 
+        reference sequences. These files are specified by unique
         <i><a href="#UD">UD identifiers</a></i>, which are returned by Mutalyzer
         after upload (See the <a href="#GenBankUploader">Reference File Loader</a>
         section for more information).<br>
@@ -121,16 +121,16 @@
       <p>
         Locus Reference Genomic (LRG) files containing uniquely and stable
         reference DNA sequences along with all relevant transcript and protein
-        sequences essential to the description of gene variants (see the 
+        sequences essential to the description of gene variants (see the
         <a href="http://www.lrg-sequence.org/"> LRG website</a> for more
-        information). LRG files are based on 
-        <a href="http://www.ncbi.nlm.nih.gov/">NCBI</a>'s 
+        information). LRG files are based on
+        <a href="http://www.ncbi.nlm.nih.gov/">NCBI</a>'s
         <a href="http://www.ncbi.nlm.nih.gov/RefSeq/RSG/">RefSeqGene project</a>
         and created in collaboration with the community of research and
         diagnostic labs, LSDB curators and mutation consortia. LRG files are
         specified by the prefix &quot;LRG_&quot; followed by a number (e.g.,
         LRG_1). The <a href="http://www.lrg-sequence.org/"> LRG website</a>
-        lists existing LRG sequences and has an 
+        lists existing LRG sequences and has an
         <a href="ftp://ftp.ebi.ac.uk/pub/databases/lrgex/">FTP site</a> for
         downloading LRGs. To maintain LRG stability, Mutalyzer's Reference File Loader does
         not accept user-defined LRG files.
@@ -140,7 +140,7 @@
       <p>
         The Mutalyzer nomenclature checker accepts variant descriptions in
         standard human sequence variant nomenclature format. For users, who are
-        not familiar with the nomenclature syntax, Mutalyzer's 
+        not familiar with the nomenclature syntax, Mutalyzer's
         <a href="#NameGenerator">Name Generator</a> provides a form to acquire
         the separate components necessary to construct variant descriptions.
       </p>
@@ -207,7 +207,7 @@
       </p>
       <p>
         The <i>Non-coding DNA</i> or <i>ncDNA</i> position numbering scheme can
-        be used with:<br> 
+        be used with:<br>
         a) <i> GenBank</i> records containing genomic sequences with annotated
         transcripts without a corresponding coding sequence.<br>
         b) LRG records<br>
@@ -247,10 +247,10 @@
         The value 1 is assigned to the A of the ATG start codon and all the
         exonic bases between start and stop are counted normally.<br>
         5' untranslated region: Exonic bases upstream of (i.e. before) the ATG
-        are numbered -1, -2, -3 and so on.<br> 
+        are numbered -1, -2, -3 and so on.<br>
         3' untranslated region: Exonic bases downstream of (i.e. behind) the
         stop codon are numbered *1, *2, *3 and so on.<br>
-        Intronic bases in the Coding sequence are numbered x+1, x+2, x+3, ... 
+        Intronic bases in the Coding sequence are numbered x+1, x+2, x+3, ...
         y-3, y-2, y-1 where x is the value of the last exonic base
         upstream of the intron, y is the value of the first exonic base
         downstream of the intron and x and y are consecutive numbers. Intronic
@@ -485,7 +485,7 @@
       </p>
 
       <hr>
-      
+
       <h3>Mutalyzer Name Checker Help<a name="NameChecker"></a></h3>
       <p>
         Users can check the correctness of a variant description. The Name
@@ -494,15 +494,15 @@
       </p>
       <p>
         Examples: <br>
-        AB026906.1:c.3_4insG<br> 
-        AB026906.1:c.[1del;4G&gt;T]<br> 
-        AL449423.14(CDKN2A_v1):c.1_10del<br> 
+        AB026906.1:c.3_4insG<br>
+        AB026906.1:c.[1del;4G&gt;T]<br>
+        AL449423.14(CDKN2A_v1):c.1_10del<br>
         UD_127955523176(DMD_v002):c.136G&gt;T<br>
         LRG_1t1:c.266G&gt;T
       </p>
 
       <hr>
-      
+
       <h3>Mutalyzer Syntax Checker Help<a name="SyntaxChecker"></a></h3>
       <p>
         Users can check the correctness of the standard nomenclature syntax.
@@ -517,9 +517,9 @@
         AB026906.1:c.35_36ins<br>
         LRG_1t1:c.266G&gt;T
       </p>
-      
+
       <hr>
-      
+
       <h3>
         Mutalyzer Position Converter Help<a name="PositionConverter"></a>
       </h3>
@@ -528,23 +528,23 @@
         description from the chromosomal position for a specific human genome
         build to a position relative to RefSeq transcript reference sequences.
         The Position Converter uses a local database containing the mapping
-        information from the 
+        information from the
         <a href="http://genome.ucsc.edu/index.html?org=Human"
           >UCSC genome browser</a> for human genome builds hg18 (NCBI 36) and
         hg19 (GRCh37). The specified version of the RefSeq transcript Accession
         number has to be present in the database. The sequence variation
-        description has <u>not</u> been checked by Mutalyzer's 
+        description has <u>not</u> been checked by Mutalyzer's
         <a href="#NameChecker">Name Checker</a>.
       </p>
       <p>
         Examples:<br>
-        NM_003002.2:c.274G&gt;T<br> 
-        chr11:g.111959693G&gt;T<br> 
+        NM_003002.2:c.274G&gt;T<br>
+        chr11:g.111959693G&gt;T<br>
         NC_000011.9:g.111959693G&gt;T
       </p>
 
       <hr>
-      
+
       <h3>Mutalyzer SNP Converter Help<a name="SNPConverter"></a></h3>
       <p>
         The SNP Converter will submit a <a
@@ -560,7 +560,7 @@
       </p>
 
       <hr>
-      
+
       <h3>Mutalyzer Name Generator Help<a name="NameGenerator"></a></h3>
       <p>
         The Name Generator aims to assist users, who are not familiar with all
@@ -573,28 +573,28 @@
       </p>
       <p>
         Example: <br>
-        Reference: AL449423.14<br> 
-        Sequence Type: Coding DNA<br> 
-        Gene symbol: CDKN2A<br> 
+        Reference: AL449423.14<br>
+        Sequence Type: Coding DNA<br>
+        Gene symbol: CDKN2A<br>
         Transcript: v_1
       </p>
       <p>
-        Variant 1<br> 
-        Mutation Type: Substitution<br> 
-        Start Position: 112<br> End Position: 112<br> 
-        Deleted Sequence: C<br> 
+        Variant 1<br>
+        Mutation Type: Substitution<br>
+        Start Position: 112<br> End Position: 112<br>
+        Deleted Sequence: C<br>
         Inserted Sequence: T
       </p>
 
       <hr>
-      
+
       <h3>Mutalyzer Batch Checker Help<a name="BatchChecker"></a></h3>
       <p>
         <br>
         The Batch checkers support submission of files containing large
-        datasets to the <a href="#NameChecker">Name Checker</a>, 
-        <a href="#SyntaxChecker">Syntax Checker</a>, and 
-        <a href="#PositionConverter">Position Converter</a> tools. 
+        datasets to the <a href="#NameChecker">Name Checker</a>,
+        <a href="#SyntaxChecker">Syntax Checker</a>, and
+        <a href="#PositionConverter">Position Converter</a> tools.
       </p>
       <p>The Mutalyzer batch checker accepts the following file formats
         <ul>
@@ -603,7 +603,7 @@
             <li>OpenOffice .odt File</li>
         </ul>
       </p>
-      
+
       <h5>
         We accept two types of input files, you can download examples below
       </h5>
@@ -627,7 +627,7 @@
       </div>
 
       <h5>
-        Old Style: 
+        Old Style:
         <a href="downloads/batchtestold.txt">Download Example File</a>
       </h5>
       <div style="padding-left:20px; width:400px">
@@ -658,7 +658,7 @@
         Users can upload a tab-delimited text file&nbsp;with the sequence
         variations to be checked. Files for the Name Checker and the Syntax
         Checker may contain any combination of reference sequences and sequence
-        types for different genes. Mutalyzer's 
+        types for different genes. Mutalyzer's
         <i><a href="#UD">UD identifiers</a></i> can also be used, but we
         strongly suggest to update any GenBank record following
         <a href="http://www.ncbi.nlm.nih.gov/Genbank/update.html"
@@ -677,9 +677,9 @@
         Internet Explorer, progress may not be reported correctly. Adding
         Mutalyzer to your trusted sites is one option to solve this.
       </p>
-      
+
       <hr>
-      
+
       <h2>Mutalyzer Output</h2>
       <p>
         Mutalyzer has been designed to issue warnings, when correcting entries,
@@ -692,7 +692,7 @@
       </p>
       <p>
         &lt;<i>Accession Number</i>&gt;.&lt;<i>version number&gt;</i>:<i>&lt;sequence type</i>&gt;.&lt;<i >mutation</i>&gt;<br>
-        
+
         (Examples: NM_003002.1:c.5delC or AL449423.14:g.61866_85191del)<br>
         or<br>
         &lt;<i>Accession Number</i>&gt;.&lt;<i>version number&gt;&lt;(Gene Symbol)&gt;</i>:<i >&lt;sequence type</i>&gt;.&lt;<i >mutation</i>&gt;<br>
@@ -717,7 +717,7 @@
         arginine substituted for a proline at position 2).
       </p>
       <p>
-        Please note the following: 
+        Please note the following:
       </p>
       <p>
         - Sequence variation descriptions using genomic references in
@@ -731,12 +731,12 @@
           on the selected Sequence Type. Example: 4506864:c.5del will be
           converted into NM_003002.1:c.5delC
       </p>
-      
+
       <hr>
-      
+
       <h3>Reference File Loader Help<a name="GenBankUploader"></a></h3>
       <p>
-        Users can upload their own reference sequence file in 
+        Users can upload their own reference sequence file in
         <a href="http://www.ncbi.nlm.nih.gov/Sitemap/samplerecord.html"
           >GenBank Flat file format</a>, retrieve the genomic sequence of a
         gene with its flanking regions, or specify a chromosomal range for use
@@ -770,11 +770,11 @@
       <p>
         Enter the URL of the website, where the Genbank Flat file with a .gb
         extension can be found and press the submit button.
-      </p> 
+      </p>
       <p>&nbsp;</p>
       <p>
         <b>
-          Retrieve part of the reference genome for a 
+          Retrieve part of the reference genome for a
           (<a href="http://www.genenames.org">HGNC</a>) gene symbol
         </b>
       </p>
@@ -809,7 +809,7 @@
           <tr>
             <td>Number of 3' flanking nucleotides</td>
             <td><input type="text" name="3utr" value="2000"></td>
-          </tr>               	
+          </tr>
        	</table>
       </div>
       <p>
@@ -860,7 +860,7 @@
           Your reference sequence was loaded successfully. You now can use
           mutalyzer with the following accession number as reference:
           UD_127955523176 <br>
-          Download this reference sequence. 
+          Download this reference sequence.
         </p>
       </div>
       <p>
@@ -872,20 +872,20 @@
 
       <hr>
 
-      <h3>Mutalyzer Webservices <a name="Webservices"></a></h3>
+      <h3>Mutalyzer Web services <a name="Webservices"></a></h3>
       <p>
-        Mutalyzer's webservices provide programmatic access to different parts
-        of Mutalyzer's functionality. In the future, these will be used by 
+        Mutalyzer's web services provide programmatic access to different parts
+        of Mutalyzer's functionality. In the future, these will be used by
         <a href="http://www.LOVD.nl">LOVD</a> to convert coding DNA positions
         to chromosomal positions for mapping and display purposes. A full
-        description of available webservices can be found at the 
-        <a href="documentation">Webservice documentation page</a>. 
-        Example scripts and requirements can be found at the 
-        <a href="webservices">Webservice page</a>.
+        description of available web services can be found at the
+        <a href="documentation">Web service documentation page</a>.
+        Example scripts and requirements can be found at the
+        <a href="webservices">Web service page</a>.
       </p>
 
       <hr>
-      
+
       <h3>Using Mutalyzer with sequences from other organisms</h3>
       <p>
         Mutalyzer can process Genbank reference files from other organisms than
@@ -906,13 +906,13 @@
         replicates the input of the user. Most errors occurring after mistyping
         should be easy to understand and can be corrected immediately by
         altering the data in the field specified. In other cases, Mutalyzer
-        should advise you to contact 
+        should advise you to contact
         <a href="mailto:Mutalyzer@humgen.nl">us</a> when the error persists.
         Please specify your input and which tool you used.
       </p>
       <p>
         Occasionally, Mutalyzer will display an Internal Server Error message
-        due to unexpected behavior. You can use Mutalyzer's 
+        due to unexpected behavior. You can use Mutalyzer's
         <a href="https://humgenprojects.lumc.nl/trac/mutalyzer"
           >bugtracking system</a> to report errors and send in feature requests.
       </p>
@@ -923,7 +923,7 @@
         Ophuizen E, den Dunnen JT, Taschner PE. Improving sequence variant
         descriptions in mutation databases and literature using the MUTALYZER
         sequence variation nomenclature checker.
-        <a href="http://www.ncbi.nlm.nih.gov/entrez/utils/fref.fcgi?PrId=3058&itool=AbstractPlus-def&uid=18000842&db=pubmed&url=http://dx.doi.org/10.1002/humu.20654">Hum Mutat 29:6-13 (2008)</a> 
+        <a href="http://www.ncbi.nlm.nih.gov/entrez/utils/fref.fcgi?PrId=3058&itool=AbstractPlus-def&uid=18000842&db=pubmed&url=http://dx.doi.org/10.1002/humu.20654">Hum Mutat 29:6-13 (2008)</a>
         [<a href="http://www.ncbi.nlm.nih.gov/pubmed/18000842?"
           >PMID: 18000842</a>].
       </p>
@@ -933,7 +933,7 @@
         specifications provided by Peter E. M. Taschner and Johan T. den
         Dunnen. The different parts of the nomenclature checker functionality
         have been separated into modules, which can be used as independent
-        webservices and undergo further development and extension in the
+        web services and undergo further development and extension in the
         future.
       </p>
 
@@ -942,7 +942,7 @@
       <p>
         If you have any comments or suggestions be sure to let us know!
       </p>
-      
+
       <p>
         Last modified: November 5, 2010
       </p>
diff --git a/mutalyzer/templates/index.html b/mutalyzer/templates/index.html
index 87760fa25c0f27087ced1341caa5140a31bef2c6..e248df27f794f3269674fa02828b014ba3a111c2 100644
--- a/mutalyzer/templates/index.html
+++ b/mutalyzer/templates/index.html
@@ -6,14 +6,14 @@
     <div metal:define-macro="content">
       <center><h3>Welcome to the Mutalyzer web site</h3></center>
       <br>
-      
+
       The aim of this program suite is to support checks of sequence variant
-      nomenclature according to the 
-      <a href="http://www.hgvs.org/mutnomen/">guidelines</a> of the 
+      nomenclature according to the
+      <a href="http://www.hgvs.org/mutnomen/">guidelines</a> of the
       <a href="http://www.hgvs.org">Human Genome Variation Society</a>.<br>
       <br>
       <br>
-      
+
       Different interfaces are provided to collect the information necessary
       for the checks:
       <ul>
@@ -54,8 +54,8 @@
           checks.
         </li>
         <li>
-          The <a href = "webservices">Webservices</a> page provides instructions
-          for the webservices.
+          The <a href = "webservices">Web services</a> page provides instructions
+          for the web services.
         </li>
       </ul>
       <br>
@@ -65,11 +65,11 @@
       Python Scripting Language was chosen for good readability and therefore
       easy maintenance.<br>
       -->
-      GenBank sequences are retrieved from the 
-      <a href="http://www.ncbi.nlm.nih.gov/">NCBI</a> 
+      GenBank sequences are retrieved from the
+      <a href="http://www.ncbi.nlm.nih.gov/">NCBI</a>
       (<a href="http://eutils.ncbi.nlm.nih.gov/About/disclaimer.html"
       >Copyright and Disclaimers</a>).<br>
-      This project is sponsored by 
+      This project is sponsored by
       <a href = "http://www.sun.com">SUN Microsystems</a> with server
       hardware within the scope of the Academic Excellence Grant (AEG)
       program (award EDUD-7832-080223-CNE).<br>
diff --git a/mutalyzer/templates/menu.html b/mutalyzer/templates/menu.html
index cd1665f3d79706b75c4d11de61bcf70e0fe889ce..b32ffeed53860dfa1edaa926cca6084d63f763bb 100644
--- a/mutalyzer/templates/menu.html
+++ b/mutalyzer/templates/menu.html
@@ -209,7 +209,7 @@
       <tr tal:attributes="class active/webservices">
         <td valign="top" width="20" class="bullet"></td>
         <td colspan="3">
-          <a href="webservices">Webservices</a>
+          <a href="webservices">Web services</a>
         </td>
       </tr>
 
@@ -281,7 +281,7 @@
         <td></td>
         <td valign="baseline" width="10" class="bullet sub"></td>
         <td colspan="2">
-          <a href="http://www.hgvs.org/mutnomen/HGVS_extend_PT.doc"
+          <a href="http://dx.doi.org/10.1002/humu.21427"
            >HGVS Nomenclature Extension Proposal</a>
         </td>
       </tr>
diff --git a/mutalyzer/templates/textmining.py b/mutalyzer/templates/textmining.py
index edf6d53a811997e0c355e297c739d8bbc4df5c3b..e48fb350d4d00fc79dab41ab984145f263655e64 100644
--- a/mutalyzer/templates/textmining.py
+++ b/mutalyzer/templates/textmining.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Example SOAP client for the Mutalyzer webservice in Python using the
+# Example SOAP client for the Mutalyzer web service in Python using the
 # SOAPpy library.
 #
 # See {path}/webservices
diff --git a/mutalyzer/templates/webservices.html b/mutalyzer/templates/webservices.html
index c9dbd3040e54ba6496e2780586343f0098b63225..5ce11fdd6d58b657636211edf1fa2a99b2c97291 100644
--- a/mutalyzer/templates/webservices.html
+++ b/mutalyzer/templates/webservices.html
@@ -5,19 +5,19 @@
   <body>
     <div metal:define-macro="content">
     <center>
-      <h3>Webservices</h3>
+      <h3>Web services</h3>
     </center>
     <br>
-    Most Mutalyzer functionality is programmatically available trough two
-    interfaces: a SOAP webservice and a HTTP/RPC+JSON webservice.
+    Most Mutalyzer functionality is programmatically available through two
+    interfaces: a SOAP web service and a HTTP/RPC+JSON web service.
     <br>
-    <h3>SOAP webservice</h3>
+    <h3>SOAP web service</h3>
     A <a href="services/?wsdl">WSDL description</a> is available
     for easy generation of client programs in many languages. See the
     <a href = "soap-api">annotated API</a> for detailed documentation.
     <br>
     <br>
-    The following are some example client programs for SOAP webservice. They
+    The following are some example client programs for SOAP web service. They
     use the <a href="documentation#op.checkSyntax">checkSyntax</a> method
     to determine if a variant description adheres to the <span class="helper"
       title="Human Genome Variation Society standard variant nomenclature">
@@ -37,8 +37,8 @@
     Here is an example that could be used for
       <a href="download/textmining.py">text mining</a> on a
       <a href="downloads/textmining_sample.txt">sample</a> input file.
-    <h3>HTTP/RPC+JSON webservice</h3>
-    The HTTP/RPC+JSON webservice is experimental and currently undocumented.
+    <h3>HTTP/RPC+JSON web service</h3>
+    The HTTP/RPC+JSON web service is experimental and currently undocumented.
     It can be called using HTTP GET requests on <code tal:content = "structure string:${location}${serviceJsonLocation}/method?param=value"></code> where <code>method</code> is the name    of the method to be called and method parameters are expected as <code>param=value</code> query string parameters. Responses are JSON-encoded.
     <br>
     <br>
@@ -47,7 +47,7 @@
     <br>
     For now, you can work from this example using the above mentioned
     <a href="soap-api">annotated SOAP API</a>, since the HTTP/RPC+JSON
-    webservice mirrors the functionality of the SOAP webservice.
+    web service mirrors the functionality of the SOAP web service.
   </div>
   </body>
 </html>
diff --git a/tests/test_services_soap.py b/tests/test_services_soap.py
index 8f1ba62c56d46dec11c0a2ab02b6c5af95ba3c38..c3b40998f867e5a58b231157047bffb1563e7e4c 100644
--- a/tests/test_services_soap.py
+++ b/tests/test_services_soap.py
@@ -52,7 +52,7 @@ class TestServicesSoap():
     """
     def setUp(self):
         """
-        Initialize webservice entrypoint.
+        Initialize web service entrypoint.
 
         @todo: Start the standalone server and stop it in self.tearDown
         instead of depending on some running instance at a fixed address.
diff --git a/tests/test_website.py b/tests/test_website.py
index 97aed79e72d529d5aa2213ff8dc71cac8cd84a56..0ebd36601a33deb738642d90575604dbd70b1eba 100644
--- a/tests/test_website.py
+++ b/tests/test_website.py
@@ -621,7 +621,7 @@ facilisi."""
 
     def test_download_py(self):
         """
-        Download a Python example client for the webservice.
+        Download a Python example client for the web service.
         """
         r = self.app.get('/download/client-suds.py')
         assert_equal(r.content_type, 'text/plain')
@@ -629,7 +629,7 @@ facilisi."""
 
     def test_download_rb(self):
         """
-        Download a Ruby example client for the webservice.
+        Download a Ruby example client for the web service.
         """
         r = self.app.get('/download/client-savon.rb')
         assert_equal(r.content_type, 'text/plain')
@@ -637,7 +637,7 @@ facilisi."""
 
     def test_download_cs(self):
         """
-        Download a C# example client for the webservice.
+        Download a C# example client for the web service.
         """
         r = self.app.get('/download/client-mono.cs')
         assert_equal(r.content_type, 'text/plain')
@@ -645,7 +645,7 @@ facilisi."""
 
     def test_download_php(self):
         """
-        Download a PHP example client for the webservice.
+        Download a PHP example client for the web service.
         """
         r = self.app.get('/download/client-php.php')
         assert_equal(r.content_type, 'text/plain')
diff --git a/mutalyzer/website.py b/mutalyzer/website.py
index 987009304efb701f959febcea01a2ab074f890f3..f7c9084d715d5bbed5bab11d77f10a88d9a43045 100644
--- a/mutalyzer/website.py
+++ b/mutalyzer/website.py
@@ -318,10 +318,10 @@ class Reference:
 
         This is used by LOVD to quickly check if a reference file is in the
         cache. If it isn't, it will resubmit it.
         Of course a more proper solution here would be to have some webservice
         method which checks if the GenBank file is in the cache *or* can be
         reconstructed from the information in the database. Because if the
         latter is the case, Mutalyzer will add it to the cache on the fly.
         """
         file_path = os.path.join(config.get('cache'), '%s.bz2' % file)
 
@@ -1444,11 +1444,11 @@ class Uploader:
 
 class SoapApi:
     """
-    SOAP webservice documentation.
+    SOAP web service documentation.
     """
     def GET(self):
         """
         HTML documentation for the webservice.
 
         Generate the documentation by a XSL transform of the WSDL document.
         The XSL transformation used is from Tomi Vanek:
@@ -1465,7 +1465,7 @@ class SoapApi:
             .documentation { white-space: pre-line; }
 
         @todo: Use some configuration setting for the location of the
-               webservice.
+               web service.
         @todo: Use configuration value for .xsl location.
         @todo: Cache this transformation.
         """
@@ -318,10 +318,10 @@ class Reference:
         This is used by LOVD to quickly check if a reference file is in the
         cache. If it isn't, it will resubmit it.
-        Of course a more proper solution here would be to have some webservice
-        method which checks if the GenBank file is in the cache *or* can be
-        reconstructed from the information in the database. Because if the
-        latter is the case, Mutalyzer will add it to the cache on the fly.
+        Of course a more proper solution here would be to have some web
+        service method which checks if the GenBank file is in the cache *or*
+        can be reconstructed from the information in the database. Because if
+        the latter is the case, Mutalyzer will add it to the cache on the fly.
         """
         file_path = os.path.join(config.get('cache'), '%s.bz2' % file)
@@ -1444,11 +1444,11 @@ class Uploader:
     def GET(self):
         """
-        HTML documentation for the webservice.
+        HTML documentation for the web service.
 
         Generate the documentation by a XSL transform of the WSDL document.